@@ -1,6 +1,6 @@
 /*
  * repmgr-client.h
- * Copyright (c) 2ndQuadrant, 2010-2020
+ * Copyright (c) EnterpriseDB Corporation, 2010-2021
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -99,6 +99,8 @@
 #define OPT_REPLICATION_CONFIG_OWNER	   1046
 #define OPT_DB_CONNECTION				   1047
 #define OPT_VERIFY_BACKUP				   1048
+#define OPT_RECOVERY_MIN_APPLY_DELAY       1049
+#define OPT_REPMGRD						   1050
 
 /* These options are for internal use only */
 #define OPT_CONFIG_ARCHIVE_DIR			   2001
@@ -164,6 +166,7 @@ static struct option long_options[] =
 	{"without-barman", no_argument, NULL, OPT_WITHOUT_BARMAN},
 	{"replication-conf-only", no_argument, NULL, OPT_REPLICATION_CONF_ONLY},
 	{"verify-backup", no_argument, NULL, OPT_VERIFY_BACKUP },
+	{"recovery-min-apply-delay", required_argument, NULL, OPT_RECOVERY_MIN_APPLY_DELAY },
 	/* deprecate this once Pg11 and earlier are unsupported */
 	{"recovery-conf-only", no_argument, NULL, OPT_REPLICATION_CONF_ONLY},
 
@@ -191,6 +194,7 @@ static struct option long_options[] =
 	{"role", no_argument, NULL, OPT_ROLE},
 	{"slots", no_argument, NULL, OPT_SLOTS},
 	{"missing-slots", no_argument, NULL, OPT_MISSING_SLOTS},
+	{"repmgrd", no_argument, NULL, OPT_REPMGRD},
 	{"has-passfile", no_argument, NULL, OPT_HAS_PASSFILE},
 	{"replication-connection", no_argument, NULL, OPT_REPL_CONN},
 	{"data-directory-config", no_argument, NULL, OPT_DATA_DIRECTORY_CONFIG},
